@@ -87,6 +87,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -444,7 +445,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info.density,argv[i]);
                 }
               break;
             }
@@ -456,7 +457,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&displacement_geometry,argv[i]);
+                  (void) CloneString(&displacement_geometry,argv[i]);
                   compose=DisplaceCompositeOp;
                 }
               break;
@@ -469,7 +470,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  CloneString(&image_info.server_name,argv[i]);
+                  (void) CloneString(&image_info.server_name,argv[i]);
                 }
               break;
             }
@@ -501,7 +502,7 @@ int main(int argc,char **argv)
               i++;
               if (i == argc)
                 MagickError(OptionError,"Missing font name",option);
-              CloneString(&image_info.font,argv[i]);
+              (void) CloneString(&image_info.font,argv[i]);
             }
           break;
         }
@@ -515,7 +516,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&geometry,argv[i]);
+                  (void) CloneString(&geometry,argv[i]);
                 }
               break;
             }
@@ -679,7 +680,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.size,argv[i]);
+                  (void) CloneString(&image_info.size,argv[i]);
                 }
               break;
             }
