@@ -133,7 +133,6 @@
 %    -threshold value     threshold the image
 %    -transparent color   make this color transparent within the image
 %    -treedepth value     depth of the color classification tree
-%    -undercolor geometry control undercolor removal and black generation
 %    -units type          PixelsPerInch, PixelsPerCentimeter, or Undefined
 %    -verbose             print detailed information about the image
 %    -view                FlashPix viewing transforms
@@ -152,6 +151,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -324,7 +324,6 @@ static void Usage(const char *client_name)
       "-threshold value     threshold the image",
       "-transparent color   make this color transparent within the image",
       "-treedepth value     depth of the color classification tree",
-      "-undercolor geometry control undercolor removal and black generation",
       "-units type          Inch, Centimeter, or Undefined",
       "-verbose             print detailed information about the image",
       "-view                FlashPix viewing transforms",
@@ -492,7 +491,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing background color",option);
-                  CloneString(&image_info.background_color,argv[i]);
+                  (void) CloneString(&image_info.background_color,argv[i]);
                 }
               break;
             }
@@ -524,7 +523,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing border color",option);
-                  CloneString(&image_info.border_color,argv[i]);
+                  (void) CloneString(&image_info.border_color,argv[i]);
                 }
               break;
             }
@@ -536,7 +535,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing box color",option);
-                  CloneString(&image_info.border_color,argv[i]);
+                  (void) CloneString(&image_info.border_color,argv[i]);
                 }
               break;
             }
@@ -704,7 +703,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info.density,argv[i]);
                 }
               break;
             }
@@ -730,7 +729,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  CloneString(&image_info.server_name,argv[i]);
+                  (void) CloneString(&image_info.server_name,argv[i]);
                 }
               break;
             }
@@ -844,7 +843,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing font name",option);
-                  CloneString(&image_info.font,argv[i]);
+                  (void) CloneString(&image_info.font,argv[i]);
                 }
               break;
             }
@@ -1061,7 +1060,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing matte color",option);
-                  CloneString(&image_info.matte_color,argv[i]);
+                  (void) CloneString(&image_info.matte_color,argv[i]);
                 }
               break;
             }
@@ -1168,7 +1167,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing pen color",option);
-                  CloneString(&image_info.pen,argv[i]);
+                  (void) CloneString(&image_info.pen,argv[i]);
                 }
               break;
             }
@@ -1408,7 +1407,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.size,argv[i]);
+                  (void) CloneString(&image_info.size,argv[i]);
                 }
               break;
             }
@@ -1455,7 +1454,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing filename",option);
-                  CloneString(&image_info.texture,argv[i]);
+                  (void) CloneString(&image_info.texture,argv[i]);
                 }
               break;
             }
@@ -1494,19 +1493,6 @@ int main(int argc,char **argv)
         }
         case 'u':
         {
-          if (strncmp("undercolor",option+1,3) == 0)
-            {
-              image_info.undercolor=(char *) NULL;
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing undercolor geometry",
-                      option);
-                  CloneString(&image_info.undercolor,argv[i]);
-                }
-              break;
-            }
           if (strncmp("units",option+1,3) == 0)
             {
               image_info.units=UndefinedResolution;
@@ -1542,7 +1528,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing view transform",option);
-                  CloneString(&image_info.view,argv[i]);
+                  (void) CloneString(&image_info.view,argv[i]);
                 }
               break;
             }
