@@ -65,6 +65,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -200,7 +201,7 @@ int main(int argc,char **argv)
                     i++;
                     if ((i == argc) || !IsGeometry(argv[i]))
                       MagickError(OptionError,"Missing geometry",option);
-                    CloneString(&image_info.size,argv[i]);
+                    (void) CloneString(&image_info.size,argv[i]);
                   }
                 break;
               }
@@ -252,8 +253,6 @@ int main(int argc,char **argv)
     {
       if (p->scene == 0)
         p->scene=count++;
-      if (image_info.verbose)
-        NumberColors(p,(FILE *) NULL);
       DescribeImage(p,stdout,image_info.verbose);
     }
     DestroyImages(image);
