@@ -104,6 +104,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -377,7 +378,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing border color",option);
-                  CloneString(&image_info.border_color,argv[i]);
+                  (void) CloneString(&image_info.border_color,argv[i]);
                 }
               break;
             }
@@ -517,7 +518,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info.density,argv[i]);
                 }
               break;
             }
@@ -534,7 +535,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  CloneString(&image_info.server_name,argv[i]);
+                  (void) CloneString(&image_info.server_name,argv[i]);
                 }
               break;
             }
@@ -779,7 +780,7 @@ int main(int argc,char **argv)
           i++;
           if (i == argc)
             MagickError(OptionError,"Missing id, name, or 'root'",option);
-          CloneString(&target_window,argv[i]);
+          (void) CloneString(&target_window,argv[i]);
           break;
         }
         case 'v':
