@@ -1,3 +1,13 @@
+/*
+  Methods to Interactively Display and Edit an Image.
+*/
+#ifndef _DISPLAY_H
+#define _DISPLAY_H
+
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 /*
   Define declarations.
 */
@@ -1512,3 +1522,9 @@ static void
   XSetCropGeometry(Display *,XWindows *,RectangleInfo *,Image *),
   XScreenEvent(Display *,XWindows *,XEvent *),
   XTranslateImage(Display *,XWindows *,Image *,const KeySym);
+
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
+#endif
