@@ -1,5 +1,5 @@
 /*
-  ImageMagick Quantization declarations.
+  ImageMagick Image Methods.
 */
 #ifndef _IMAGE_H
 #define _IMAGE_H
@@ -8,88 +8,6 @@
 extern "C" {
 #endif
 
-/*
-  Image define declarations.
-*/
-#define alias  antialias
-#define Alphabet  "`-=[]\\;',./~!@#$%^&*()_+{}|:\"<>?" \
-  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-#define ColorMatch(color,target,distance) \
-  (((((color).red-(int) (target).red)*((color).red-(int) (target).red))+ \
-    (((color).green-(int) (target).green)*((color).green-(int) (target).green))+ \
-    (((color).blue-(int) (target).blue)*((color).blue-(int) (target).blue))) <= \
-    (distance*distance))
-#define DegreesToRadians(x) ((x)*M_PI/180.0)
-#define Intensity(color)  \
-  ((unsigned int) ((color).red*77+(color).green*150+(color).blue*29) >> 8)
-#define IsFaxImage(color)  \
-  (IsMonochromeImage(image) && ((image)->columns <= 2560))
-#define IsGray(color)  \
-  (((color).red == (color).green) && ((color).green == (color).blue))
-#define MatteMatch(color,target,delta) \
-  (ColorMatch(color,target,delta) && ((color).index == (target).index))
-#define MaxColormapSize  65535L
-#define MaxStacksize  (1 << 15)
-#define MaxTextExtent  1664
-#define Opaque  MaxRGB
-#define PixelOffset(image,x,y) \
-  ((image)->pixels+(((int) (y))*(image)->columns+((int) (x))))
-#define Push(up,left,right,delta) \
-  if ((p < (segment_stack+MaxStacksize)) && (((up)+(delta)) >= 0) && \
-      (((up)+(delta)) < (int) image->rows)) \
-    { \
-      p->y1=(up); \
-      p->x1=(left); \
-      p->x2=(right); \
-      p->y2=(delta); \
-      p++; \
-    }
-#define RadiansToDegrees(x) ((x)*180/M_PI)
-#define ReadQuantum(quantum,p)  \
-{  \
-  if (image->depth <= 8) \
-    quantum=UpScale(*p++); \
-  else \
-    { \
-      value=(*p++) << 8;  \
-      value|=(*p++);  \
-      quantum=value >> (image->depth-QuantumDepth); \
-    } \
-}
-#define ReadQuantumFile(quantum)  \
-{  \
-  if (image->depth <= 8) \
-    quantum=UpScale(fgetc(image->file)); \
-  else \
-    quantum=MSBFirstReadShort(image->file) >> (image->depth-QuantumDepth); \
-}
-#define SharpenFactor  60.0
-#define Transparent  0
-#define UncompressImage  UncondenseImage
-#define WriteQuantum(quantum,q)  \
-{  \
-  if (image->depth <= 8) \
-    *q++=DownScale(quantum); \
-  else \
-    { \
-      value=(quantum); \
-      if ((QuantumDepth-image->depth) > 0) \
-        value*=257; \
-      *q++=value >> 8; \
-      *q++=value; \
-    } \
-}
-#define WriteQuantumFile(quantum)  \
-{  \
-  if (image->depth <= 8) \
-    (void) fputc(DownScale(quantum),image->file); \
-  else \
-    if ((QuantumDepth-image->depth) > 0) \
-      MSBFirstWriteShort((quantum)*257,image->file); \
-    else \
-      MSBFirstWriteShort(quantum,image->file); \
-}
-
 #if defined(QuantumLeap)
 /*
   Color quantum is [0..65535].
@@ -128,212 +46,6 @@ typedef unsigned char Quantum;
 #define LessValue  0x4000
 #define GreaterValue  0x8000
 
-/*
-  Enumeration declarations.
-*/
-typedef enum
-{
-  UndefinedClass,
-  DirectClass,
-  PseudoClass
-} ClassType;
-
-typedef enum
-{
-  UndefinedColorspace,
-  RGBColorspace,
-  GRAYColorspace,
-  TransparentColorspace,
-  OHTAColorspace,
-  XYZColorspace,
-  YCbCrColorspace,
-  YCCColorspace,
-  YIQColorspace,
-  YPbPrColorspace,
-  YUVColorspace,
-  CMYKColorspace,
-  sRGBColorspace
-} ColorspaceType;
-
-typedef enum
-{
-  UndefinedCompositeOp = 0,
-  OverCompositeOp,
-  InCompositeOp,
-  OutCompositeOp,
-  AtopCompositeOp,
-  XorCompositeOp,
-  PlusCompositeOp,
-  MinusCompositeOp,
-  AddCompositeOp,
-  SubtractCompositeOp,
-  DifferenceCompositeOp,
-  BumpmapCompositeOp,
-  ReplaceCompositeOp,
-  ReplaceRedCompositeOp,
-  ReplaceGreenCompositeOp,
-  ReplaceBlueCompositeOp,
-  ReplaceMatteCompositeOp,
-  BlendCompositeOp,
-  DisplaceCompositeOp,
-  AnnotateCompositeOp
-} CompositeOperator;
-
-typedef enum
-{
-  UndefinedCompression,
-  NoCompression,
-  BZipCompression,
-  FaxCompression,
-  JPEGCompression,
-  LZWCompression,
-  RunlengthEncodedCompression,
-  ZipCompression
-} CompressionType;
-
-typedef enum
-{
-  UndefinedFilter,
-  PointFilter,
-  BoxFilter,
-  TriangleFilter,
-  HermiteFilter,
-  HanningFilter,
-  HammingFilter,
-  BlackmanFilter,
-  GaussianFilter,
-  QuadraticFilter,
-  CubicFilter,
-  CatromFilter,
-  MitchellFilter,
-  LanczosFilter,
-  BesselFilter,
-  SincFilter
-} FilterType;
-
-typedef enum
-{
-  UndefinedId,
-  ImageMagickId
-} IdType;
-
-typedef enum
-{
-  UndefinedType,
-  BilevelType,
-  GrayscaleType,
-  PaletteType,
-  TrueColorType,
-  MatteType,
-  ColorSeparationType
-} ImageType;
-
-typedef enum
-{
-  UndefinedInterlace,
-  NoInterlace,
-  LineInterlace,
-  PlaneInterlace,
-  PartitionInterlace
-} InterlaceType;
-
-typedef enum
-{
-  UndefinedLayer,
-  RedLayer,
-  GreenLayer,
-  BlueLayer,
-  MatteLayer
-} LayerType;
-
-typedef enum
-{
-  UniformNoise,
-  GaussianNoise,
-  MultiplicativeGaussianNoise,
-  ImpulseNoise,
-  LaplacianNoise,
-  PoissonNoise
-} NoiseType;
-
-typedef enum
-{
-  PointMethod = 0,
-  ReplaceMethod,
-  FloodfillMethod,
-  FillToBorderMethod,
-  ResetMethod
-} PaintMethod;
-
-typedef enum
-{
-  UndefinedPreview = 0,
-  RotatePreview,
-  ShearPreview,
-  RollPreview,
-  HuePreview,
-  SaturationPreview,
-  BrightnessPreview,
-  GammaPreview,
-  SpiffPreview,
-  DullPreview,
-  GrayscalePreview,
-  QuantizePreview,
-  DespecklePreview,
-  ReduceNoisePreview,
-  AddNoisePreview,
-  SharpenPreview,
-  BlurPreview,
-  ThresholdPreview,
-  EdgeDetectPreview,
-  SpreadPreview,
-  SolarizePreview,
-  ShadePreview,
-  RaisePreview,
-  SegmentPreview,
-  SwirlPreview,
-  ImplodePreview,
-  WavePreview,
-  OilPaintPreview,
-  CharcoalDrawingPreview,
-  JPEGPreview
-} PreviewType;
-
-typedef enum
-{
-  UndefinedPrimitive = 0,
-  PointPrimitive,
-  LinePrimitive,
-  RectanglePrimitive,
-  FillRectanglePrimitive,
-  CirclePrimitive,
-  FillCirclePrimitive,
-  EllipsePrimitive,
-  FillEllipsePrimitive,
-  PolygonPrimitive,
-  FillPolygonPrimitive,
-  ColorPrimitive,
-  MattePrimitive,
-  TextPrimitive,
-  ImagePrimitive
-} PrimitiveType;
-
-typedef enum
-{
-  UndefinedIntent,
-  SaturationIntent,
-  PerceptualIntent,
-  AbsoluteIntent,
-  RelativeIntent
-} RenderingIntent;
-
-typedef enum
-{
-  UndefinedResolution,
-  PixelsPerInchResolution,
-  PixelsPerCentimeterResolution
-} ResolutionType;
-
 /*
   Typedef declarations.
 */
@@ -456,8 +168,7 @@ typedef struct _ImageInfo
   char
     *background_color,
     *border_color,
-    *matte_color,
-    *undercolor;
+    *matte_color;
 
   char
     unique[MaxTextExtent];
@@ -644,8 +355,7 @@ typedef struct _Image
     interlace;
 
   unsigned int
-    scene,
-    number_scenes;
+    scene;
 
   char
     *montage,
@@ -680,16 +390,6 @@ typedef struct _Image
     x_resolution,
     y_resolution;
 
-  unsigned int
-    mean_error_per_pixel;
-
-  double
-    normalized_mean_error,
-    normalized_maximum_error;
-
-  unsigned long
-    total_colors;
-
   char
     *signature;
 
@@ -726,6 +426,16 @@ typedef struct _Image
   FilterType
     filter;
 
+  unsigned long
+    total_colors;
+
+  unsigned int
+    mean_error_per_pixel;
+
+  double
+    normalized_mean_error,
+    normalized_maximum_error;
+
   long int
     magick_time;
 
@@ -751,30 +461,34 @@ typedef struct _Image
 /*
   Image utilities methods.
 */
+extern Export AnnotateInfo
+  *CloneAnnotateInfo(const ImageInfo *,const AnnotateInfo *);
+
 extern Export Image
-  *AddNoiseImage(Image *,NoiseType),
+  *AddNoiseImage(const Image *,const NoiseType),
   *AllocateImage(const ImageInfo *),
   *AppendImages(Image *,const unsigned int),
-  *AverageImages(Image *),
-  *BlurImage(Image *,const double),
-  *BorderImage(Image *,const RectangleInfo *),
-  *ChopImage(Image *,RectangleInfo *),
-  *CloneImage(Image *,const unsigned int,const unsigned int,const unsigned int),
+  *AverageImages(const Image *),
+  *BlurImage(const Image *,const double),
+  *BorderImage(const Image *,const RectangleInfo *),
+  *ChopImage(const Image *,const RectangleInfo *),
+  *CloneImage(const Image *,const unsigned int,const unsigned int,
+    const unsigned int),
   *CreateImage(const unsigned int,const unsigned int,const float *,
     const float *,const float *,const float *),
-  *CropImage(Image *,RectangleInfo *),
+  *CropImage(const Image *,const RectangleInfo *),
   *DespeckleImage(Image *),
-  *EdgeImage(Image *,const double),
-  *EmbossImage(Image *),
-  *EnhanceImage(Image *),
-  *FlipImage(Image *),
-  *FlopImage(Image *),
-  *FrameImage(Image *,const FrameInfo *),
-  *ImplodeImage(Image *,double),
-  **ListToGroupImage(Image *,unsigned int *),
+  *EdgeImage(const Image *,const double),
+  *EmbossImage(const Image *),
+  *EnhanceImage(const Image *),
+  *FlipImage(const Image *),
+  *FlopImage(const Image *),
+  *FrameImage(const Image *,const FrameInfo *),
+  *ImplodeImage(Image *,const double),
+  **ListToGroupImage(const Image *,unsigned int *),
   *MagnifyImage(Image *),
   *MinifyImage(Image *),
-  *MontageImages(Image *,const MontageInfo *),
+  *MontageImages(const Image *,const MontageInfo *),
   *MorphImages(Image *,const unsigned int),
   *OilPaintImage(Image *,const unsigned int),
   *ReadAVSImage(const ImageInfo *image_info),
@@ -814,9 +528,11 @@ extern Export Image
   *ReadPNMImage(const ImageInfo *image_info),
   *ReadPSDImage(const ImageInfo *image_info),
   *ReadPSImage(const ImageInfo *image_info),
+  *ReadPWPImage(const ImageInfo *image_info),
   *ReadRGBImage(const ImageInfo *image_info),
   *ReadRLAImage(const ImageInfo *image_info),
   *ReadRLEImage(const ImageInfo *image_info),
+  *ReadSFWImage(const ImageInfo *image_info),
   *ReadSGIImage(const ImageInfo *image_info),
   *ReadSTEGANOImage(const ImageInfo *image_info),
   *ReadSUNImage(const ImageInfo *image_info),
@@ -837,15 +553,16 @@ extern Export Image
   *ReadXPMImage(const ImageInfo *image_info),
   *ReadXWDImage(const ImageInfo *image_info),
   *ReadYUVImage(const ImageInfo *image_info),
-  *ReduceNoiseImage(Image *),
-  *RollImage(Image *,int,int),
-  *RotateImage(Image *,double,const unsigned int,const unsigned int),
-  *SampleImage(Image *,unsigned int,unsigned int),
-  *ScaleImage(Image *,const unsigned int,const unsigned int),
+  *ReduceNoiseImage(const Image *),
+  *RollImage(const Image *,const int,const int),
+  *RotateImage(const Image *,const double,const unsigned int,
+    const unsigned int),
+  *SampleImage(const Image *,const unsigned int,const unsigned int),
+  *ScaleImage(const Image *,const unsigned int,const unsigned int),
   *ShadeImage(Image *,const unsigned int,double,double),
-  *SharpenImage(Image *,const double),
-  *ShearImage(Image *,double,double,const unsigned int),
-  *SpreadImage(Image *,unsigned int),
+  *SharpenImage(const Image *,const double),
+  *ShearImage(const Image *,const double,const double,const unsigned int),
+  *SpreadImage(Image *,const unsigned int),
   *SteganoImage(Image *,Image *),
   *StereoImage(Image *,const Image *),
   *SwirlImage(Image *,double),
@@ -862,16 +579,15 @@ extern Export int
   ParseImageGeometry(const char *,int *,int *,unsigned int *,unsigned int *);
 
 extern Export unsigned int
+  GetNumberScenes(const Image *),
   IsGeometry(const char *),
   IsGrayImage(Image *),
   IsMonochromeImage(Image *),
   IsPseudoClass(Image *),
   IsSubimage(const char *,const unsigned int),
-  IsTainted(Image *),
-  MapImage(Image *,Image *,const unsigned int),
-  MapImages(Image *,Image *,const unsigned int),
+  IsTainted(const Image *),
   PingImage(ImageInfo *,unsigned int *,unsigned int *),
-  PlasmaImage(Image *,SegmentInfo *,int,int),
+  PlasmaImage(Image *,const SegmentInfo *,int,int),
   UncondenseImage(Image *),
   WriteAVSImage(const ImageInfo *image_info,Image *image),
   WriteBMPImage(const ImageInfo *image_info,Image *image),
@@ -926,40 +642,39 @@ extern Export unsigned int
 
 extern Export void
   AllocateNextImage(const ImageInfo *,Image *),
-  AnnotateImage(Image *,AnnotateInfo *),
+  AnnotateImage(Image *,const AnnotateInfo *),
   CloseImage(Image *),
   CoalesceImages(Image *),
-  ColorFloodfillImage(Image *,const RunlengthPacket *,const char *,int x,int y,
-    const PaintMethod),
+  ColorFloodfillImage(Image *,const RunlengthPacket *,const char *,const int x,
+    const int y,const PaintMethod),
   ColorizeImage(Image *,const char *,const char *),
   CommentImage(Image *,const char *),
   CompositeImage(Image *,const CompositeOperator,Image *,const int,const int),
   CompressColormap(Image *),
   CondenseImage(Image *),
   ContrastImage(Image *,const unsigned int),
-  CycleColormapImage(Image *,int),
+  CycleColormapImage(Image *,const int),
   DescribeImage(Image *,FILE *,const unsigned int),
   DestroyAnnotateInfo(AnnotateInfo *),
   DestroyImage(Image *),
   DestroyImageInfo(ImageInfo *),
   DestroyImages(Image *),
   DestroyMontageInfo(MontageInfo *),
-  DrawImage(Image *,AnnotateInfo *),
+  DrawImage(Image *,const AnnotateInfo *),
   EqualizeImage(Image *),
   GammaImage(Image *,const char *),
   GetAnnotateInfo(const ImageInfo *,AnnotateInfo *),
   GetImageInfo(ImageInfo *),
   GetMontageInfo(MontageInfo *),
   GetPixels(const Image *,float *,float *,float *,float *),
-  HSLTransform(double,const double,const double,Quantum *,Quantum *,Quantum *),
   LabelImage(Image *,const char *),
   LayerImage(Image *,const LayerType),
-  MatteFloodfillImage(Image *,const RunlengthPacket *,const unsigned int,int x,
-    int y,const PaintMethod),
+  MatteFloodfillImage(Image *,const RunlengthPacket *,const unsigned int,
+    const int x,const int y,const PaintMethod),
   MatteImage(Image *),
   ModulateImage(Image *,const char *),
-  MogrifyImage(ImageInfo *,const int,char **,Image **),
-  MogrifyImages(ImageInfo *,const int,char **,Image **),
+  MogrifyImage(const ImageInfo *,const int,char **,Image **),
+  MogrifyImages(const ImageInfo *,const int,char **,Image **),
   NegateImage(Image *,const unsigned int),
   NormalizeImage(Image *),
   OpaqueImage(Image *,const char *,const char *),
@@ -968,7 +683,6 @@ extern Export void
   RGBTransformImage(Image *,const ColorspaceType),
   SetImage(Image *),
   SetImageInfo(ImageInfo *,const unsigned int),
-  SetNumberScenes(Image *),
   SignatureImage(Image *),
   SolarizeImage(Image *,const double),
   SortColormapByIntensity(Image *),
