@@ -60,6 +60,7 @@
 #define _X_H
 #define _WIDGET_H
 #include "magick.h"
+#include "defines.h"
 #include "mac.h"
 #include <AppleEvents.h>
 #include <AERegistry.h>
@@ -821,7 +822,7 @@ DIR *opendir(char *path)
 %
 %
 */
-Export void ProcessPendingEvents(char *text)
+Export void ProcessPendingEvents(const char *text)
 {
   static char
     *mark = (char *) NULL;
