@@ -191,6 +191,14 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
+
+/*
+  Define declarations.
+*/
+#define CacheShift  (QuantumDepth-6)
+#define ErrorQueueLength  16
+#define MaxNodes  266817
 
 /*
   Typdef declarations.
@@ -289,8 +297,9 @@ static unsigned int
 static void
   ClosestColor(CubeInfo *,const NodeInfo *),
   DefineColormap(CubeInfo *,NodeInfo *),
-  HilbertCurve(CubeInfo *,Image *,int,unsigned int),
-  PruneLevel(CubeInfo *,const NodeInfo *);
+  HilbertCurve(CubeInfo *,Image *,const int,const unsigned int),
+  PruneLevel(CubeInfo *,const NodeInfo *),
+  Reduction(CubeInfo *,const unsigned int);
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -335,8 +344,8 @@ static void
 %
 %
 */
-static unsigned int Assignment(CubeInfo *cube_info,QuantizeInfo *quantize_info,
-  Image *image)
+static unsigned int Assignment(CubeInfo *cube_info,
+  const QuantizeInfo *quantize_info,Image *image)
 {
 #define AssignImageText  "  Assigning image colors...  "
 
@@ -353,6 +362,7 @@ static unsigned int Assignment(CubeInfo *cube_info,QuantizeInfo *quantize_info,
     index;
 
   unsigned int
+    dither,
     id;
 
   /*
@@ -390,7 +400,8 @@ static unsigned int Assignment(CubeInfo *cube_info,QuantizeInfo *quantize_info,
       image->colormap[!polarity].green=MaxRGB;
       image->colormap[!polarity].blue=MaxRGB;
     }
-  if (quantize_info->colorspace != TransparentColorspace)
+  if ((quantize_info->colorspace != TransparentColorspace) &&
+      (image->colorspace != CMYKColorspace))
     {
       image->matte=False;
       image->class=PseudoClass;
@@ -400,10 +411,11 @@ static unsigned int Assignment(CubeInfo *cube_info,QuantizeInfo *quantize_info,
     Create a reduced color image.
   */
   image->tainted=True;
-  if (quantize_info->dither)
-    quantize_info->dither=!DitherImage(cube_info,image);
+  dither=quantize_info->dither;
+  if (dither)
+    dither=!DitherImage(cube_info,image);
   p=image->pixels;
-  if (!quantize_info->dither)
+  if (!dither)
     for (i=0; i < (int) image->packets; i++)
     {
       /*
@@ -504,7 +516,7 @@ static unsigned int Assignment(CubeInfo *cube_info,QuantizeInfo *quantize_info,
 %
 %
 */
-static unsigned int Classification(CubeInfo *cube_info,Image *image)
+static unsigned int Classification(CubeInfo *cube_info,const Image *image)
 {
 #define ClassifyImageText  "  Classifying image colors...  "
 
@@ -539,8 +551,6 @@ static unsigned int Classification(CubeInfo *cube_info,Image *image)
   squares=cube_info->squares;
   cube_info->root->quantization_error=
     3.0*(MaxRGB/2.0)*(MaxRGB/2.0)*image->columns*image->rows;
-  if (image->packets == (image->columns*image->rows))
-    CondenseImage(image);
   p=image->pixels;
   for (i=0; i < (int) image->packets; i++)
   {
@@ -713,9 +723,9 @@ static void ClosestColor(CubeInfo *cube_info,const NodeInfo *node_info)
           */
           squares=cube_info->squares;
           color=cube_info->colormap+node_info->color_number;
-          distance_squared=squares[color->red-(int) cube_info->color.red]+
-            squares[color->green-(int) cube_info->color.green]+
-            squares[color->blue-(int) cube_info->color.blue];
+          distance_squared=squares[(int) color->red-(int) cube_info->color.red]+
+            squares[(int) color->green-(int) cube_info->color.green]+
+            squares[(int) color->blue-(int) cube_info->color.blue];
           if (distance_squared < cube_info->distance)
             {
               cube_info->distance=distance_squared;
@@ -838,6 +848,37 @@ static void DestroyCubeInfo(CubeInfo *cube_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D e s t r o y Q u a n t i z e I n f o                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method DestroyQuantizeInfo deallocates memory associated with an
+%  QuantizeInfo structure.
+%
+%  The format of the DestroyQuantizeInfo routine is:
+%
+%      DestroyQuantizeInfo(quantize_info)
+%
+%  A description of each parameter follows:
+%
+%    o quantize_info: Specifies a pointer to an QuantizeInfo structure.
+%
+%
+*/
+Export void DestroyQuantizeInfo(QuantizeInfo *quantize_info)
+{
+  assert(quantize_info != (QuantizeInfo *) NULL);
+  FreeMemory((QuantizeInfo *) quantize_info);
+  quantize_info=(QuantizeInfo *) NULL;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   D i t h e r                                                               %
 %                                                                             %
 %                                                                             %
@@ -863,7 +904,8 @@ static void DestroyCubeInfo(CubeInfo *cube_info)
 %      to move to next to follow the Hilbert curve.
 %
 */
-static void Dither(CubeInfo *cube_info,Image *image,unsigned int direction)
+static void Dither(CubeInfo *cube_info,Image *image,
+  const unsigned int direction)
 {
   register CubeInfo
     *p;
@@ -904,9 +946,9 @@ static void Dither(CubeInfo *cube_info,Image *image,unsigned int direction)
         green_error+=p->error[i].green*p->weights[i];
         blue_error+=p->error[i].blue*p->weights[i];
       }
-      red=p->range_limit[q->red+(int) red_error];
-      green=p->range_limit[q->green+(int) green_error];
-      blue=p->range_limit[q->blue+(int) blue_error];
+      red=p->range_limit[(int) q->red+(int) red_error];
+      green=p->range_limit[(int) q->green+(int) green_error];
+      blue=p->range_limit[(int) q->blue+(int) blue_error];
       i=(blue >> CacheShift) << 12 | (green >> CacheShift) << 6 |
         (red >> CacheShift);
       if (p->cache[i] < 0)
@@ -1148,7 +1190,7 @@ static unsigned int GetCubeInfo(CubeInfo *cube_info,unsigned int dither,
   for (i=0; i < ErrorQueueLength; i++)
   {
     cube_info->weights[ErrorQueueLength-i-1]=1.0/weight;
-    weight*=exp(log(MaxRGB+1)/(ErrorQueueLength-1));
+     weight*=exp(log((double) MaxRGB+1.0)/(ErrorQueueLength-1.0));
   }
   /*
     Normalize the weighting factors.
@@ -1295,8 +1337,8 @@ Export void GetQuantizeInfo(QuantizeInfo *quantize_info)
 %
 %
 */
-static void HilbertCurve(CubeInfo *cube_info,Image *image,int level,
-  unsigned int direction)
+static void HilbertCurve(CubeInfo *cube_info,Image *image,const int level,
+  const unsigned int direction)
 {
   if (level == 1)
     {
@@ -1385,232 +1427,6 @@ static void HilbertCurve(CubeInfo *cube_info,Image *image,int level,
       break;
   }
 }
-
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-+   P r u n e C h i l d                                                       %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method PruneChild deletes the given node and merges its statistics into
-%  its parent.
-%
-%  The format of the PruneSubtree routine is:
-%
-%      PruneChild(cube_info,node_info)
-%
-%  A description of each parameter follows.
-%
-%    o cube: A pointer to the Cube structure.
-%
-%    o node_info: pointer to node in color cube tree that is to be pruned.
-%
-%
-*/
-static void PruneChild(CubeInfo *cube_info,const NodeInfo *node_info)
-{
-  NodeInfo
-    *parent;
-
-  register int
-    id;
-
-  /*
-    Traverse any children.
-  */
-  if (node_info->census != 0)
-    for (id=0; id < 8; id++)
-      if (node_info->census & (1 << id))
-        PruneChild(cube_info,node_info->child[id]);
-  /*
-    Merge color statistics into parent.
-  */
-  parent=node_info->parent;
-  parent->census&=~(1 << node_info->id);
-  parent->number_unique+=node_info->number_unique;
-  parent->total_red+=node_info->total_red;
-  parent->total_green+=node_info->total_green;
-  parent->total_blue+=node_info->total_blue;
-  cube_info->nodes--;
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-+  P r u n e L e v e l                                                        %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method PruneLevel deletes all nodes at the bottom level of the color
-%  tree merging their color statistics into their parent node.
-%
-%  The format of the PruneLevel routine is:
-%
-%      PruneLevel(cube_info,node_info)
-%
-%  A description of each parameter follows.
-%
-%    o cube: A pointer to the Cube structure.
-%
-%    o node_info: pointer to node in color cube tree that is to be pruned.
-%
-%
-*/
-static void PruneLevel(CubeInfo *cube_info,const NodeInfo *node_info)
-{
-  register int
-    id;
-
-  /*
-    Traverse any children.
-  */
-  if (node_info->census != 0)
-    for (id=0; id < 8; id++)
-      if (node_info->census & (1 << id))
-        PruneLevel(cube_info,node_info->child[id]);
-  if (node_info->level == cube_info->depth)
-    PruneChild(cube_info,node_info);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-+   R e d u c e                                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method Reduce traverses the color cube tree and prunes any node whose
-%  quantization error falls below a particular threshold.
-%
-%  The format of the Reduce routine is:
-%
-%      Reduce(cube_info,node_info)
-%
-%  A description of each parameter follows.
-%
-%    o cube: A pointer to the Cube structure.
-%
-%    o node_info: pointer to node in color cube tree that is to be pruned.
-%
-%
-*/
-static void Reduce(CubeInfo *cube_info,const NodeInfo *node_info)
-{
-  register unsigned int
-    id;
-
-  /*
-    Traverse any children.
-  */
-  if (node_info->census != 0)
-    for (id=0; id < 8; id++)
-      if (node_info->census & (1 << id))
-        Reduce(cube_info,node_info->child[id]);
-  if (node_info->quantization_error <= cube_info->pruning_threshold)
-    PruneChild(cube_info,node_info);
-  else
-    {
-      /*
-        Find minimum pruning threshold.
-      */
-      if (node_info->number_unique > 0)
-        cube_info->colors++;
-      if (node_info->quantization_error < cube_info->next_pruning_threshold)
-        cube_info->next_pruning_threshold=node_info->quantization_error;
-    }
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-+   R e d u c t i o n                                                         %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method Reduction repeatedly prunes the tree until the number of nodes
-%  with n2 > 0 is less than or equal to the maximum number of colors allowed
-%  in the output image.  On any given iteration over the tree, it selects
-%  those nodes whose E value is minimal for pruning and merges their
-%  color statistics upward. It uses a pruning threshold, Ep, to govern
-%  node selection as follows:
-%
-%    Ep = 0
-%    while number of nodes with (n2 > 0) > required maximum number of colors
-%      prune all nodes such that E <= Ep
-%      Set Ep to minimum E in remaining nodes
-%
-%  This has the effect of minimizing any quantization error when merging
-%  two nodes together.
-%
-%  When a node to be pruned has offspring, the pruning procedure invokes
-%  itself recursively in order to prune the tree from the leaves upward.
-%  n2,  Sr, Sg,  and  Sb in a node being pruned are always added to the
-%  corresponding data in that node's parent.  This retains the pruned
-%  node's color characteristics for later averaging.
-%
-%  For each node, n2 pixels exist for which that node represents the
-%  smallest volume in RGB space containing those pixel's colors.  When n2
-%  > 0 the node will uniquely define a color in the output image. At the
-%  beginning of reduction,  n2 = 0  for all nodes except a the leaves of
-%  the tree which represent colors present in the input image.
-%
-%  The other pixel count, n1, indicates the total number of colors
-%  within the cubic volume which the node represents.  This includes n1 -
-%  n2  pixels whose colors should be defined by nodes at a lower level in
-%  the tree.
-%
-%  The format of the Reduction routine is:
-%
-%      Reduction(cube_info,number_colors)
-%
-%  A description of each parameter follows.
-%
-%    o cube: A pointer to the Cube structure.
-%
-%    o number_colors: This integer value indicates the maximum number of
-%      colors in the quantized image or colormap.  The actual number of
-%      colors allocated to the colormap may be less than this value, but
-%      never more.
-%
-%
-*/
-static void Reduction(CubeInfo *cube_info,const unsigned int number_colors)
-{
-#define ReduceImageText  "  Reducing image colors...  "
-
-  unsigned int
-    span;
-
-  span=(unsigned int) cube_info->colors;
-  cube_info->next_pruning_threshold=0.0;
-  while (cube_info->colors > number_colors)
-  {
-    cube_info->pruning_threshold=cube_info->next_pruning_threshold;
-    cube_info->next_pruning_threshold=cube_info->root->quantization_error;
-    cube_info->colors=0;
-    Reduce(cube_info,cube_info->root);
-    ProgressMonitor(ReduceImageText,(unsigned int) (span-cube_info->colors),
-      span-number_colors+1);
-  }
-}
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -1642,7 +1458,8 @@ static void Reduction(CubeInfo *cube_info,const unsigned int number_colors)
 %
 %
 */
-unsigned int MapImage(Image *image,Image *map_image,const unsigned int dither)
+unsigned int MapImage(Image *image,const Image *map_image,
+  const unsigned int dither)
 {
   CubeInfo
     cube_info;
@@ -1708,7 +1525,7 @@ unsigned int MapImage(Image *image,Image *map_image,const unsigned int dither)
 %
 %
 */
-Export unsigned int MapImages(Image *images,Image *map_image,
+Export unsigned int MapImages(Image *images,const Image *map_image,
   const unsigned int dither)
 {
   CubeInfo
@@ -1883,6 +1700,101 @@ static unsigned int OrderedDitherImage(Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   P r u n e C h i l d                                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method PruneChild deletes the given node and merges its statistics into
+%  its parent.
+%
+%  The format of the PruneSubtree routine is:
+%
+%      PruneChild(cube_info,node_info)
+%
+%  A description of each parameter follows.
+%
+%    o cube: A pointer to the Cube structure.
+%
+%    o node_info: pointer to node in color cube tree that is to be pruned.
+%
+%
+*/
+static void PruneChild(CubeInfo *cube_info,const NodeInfo *node_info)
+{
+  NodeInfo
+    *parent;
+
+  register int
+    id;
+
+  /*
+    Traverse any children.
+  */
+  if (node_info->census != 0)
+    for (id=0; id < 8; id++)
+      if (node_info->census & (1 << id))
+        PruneChild(cube_info,node_info->child[id]);
+  /*
+    Merge color statistics into parent.
+  */
+  parent=node_info->parent;
+  parent->census&=~(1 << node_info->id);
+  parent->number_unique+=node_info->number_unique;
+  parent->total_red+=node_info->total_red;
+  parent->total_green+=node_info->total_green;
+  parent->total_blue+=node_info->total_blue;
+  cube_info->nodes--;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++  P r u n e L e v e l                                                        %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method PruneLevel deletes all nodes at the bottom level of the color
+%  tree merging their color statistics into their parent node.
+%
+%  The format of the PruneLevel routine is:
+%
+%      PruneLevel(cube_info,node_info)
+%
+%  A description of each parameter follows.
+%
+%    o cube: A pointer to the Cube structure.
+%
+%    o node_info: pointer to node in color cube tree that is to be pruned.
+%
+%
+*/
+static void PruneLevel(CubeInfo *cube_info,const NodeInfo *node_info)
+{
+  register int
+    id;
+
+  /*
+    Traverse any children.
+  */
+  if (node_info->census != 0)
+    for (id=0; id < 8; id++)
+      if (node_info->census & (1 << id))
+        PruneLevel(cube_info,node_info->child[id]);
+  if (node_info->level == cube_info->depth)
+    PruneChild(cube_info,node_info);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %  Q u a n t i z a t i o n E r r o r                                          %
 %                                                                             %
 %                                                                             %
@@ -1947,10 +1859,10 @@ unsigned int QuantizationError(Image *image)
     Initialize measurement.
   */
   assert(image != (Image *) NULL);
+  image->total_colors=GetNumberColors(image,(FILE *) NULL);
   image->mean_error_per_pixel=0;
   image->normalized_mean_error=0.0;
   image->normalized_maximum_error=0.0;
-  NumberColors(image,(FILE *) NULL);
   if (image->class == DirectClass)
     return(True);
   cube_info.squares=(unsigned int *)
@@ -2022,7 +1934,8 @@ unsigned int QuantizationError(Image *image)
 %    o image: Specifies a pointer to a Image structure.
 %
 */
-Export unsigned int QuantizeImage(QuantizeInfo *quantize_info,Image *image)
+Export unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
+  Image *image)
 {
   CubeInfo
     cube_info;
@@ -2069,6 +1982,8 @@ Export unsigned int QuantizeImage(QuantizeInfo *quantize_info,Image *image)
   status=GetCubeInfo(&cube_info,quantize_info->dither,depth);
   if (status == False)
     return(False);
+  if (image->packets == (image->columns*image->rows))
+    CondenseImage(image);
   if (quantize_info->colorspace != RGBColorspace)
     RGBTransformImage(image,quantize_info->colorspace);
   status=Classification(&cube_info,image);
@@ -2077,8 +1992,6 @@ Export unsigned int QuantizeImage(QuantizeInfo *quantize_info,Image *image)
       /*
         Reduce the number of colors in the continuous tone image.
       */
-      if ((cube_info.colors >> 1) < number_colors)
-        quantize_info->dither=False;
       if (number_colors < cube_info.colors)
         Reduction(&cube_info,number_colors);
       status=Assignment(&cube_info,quantize_info,image);
@@ -2120,7 +2033,8 @@ Export unsigned int QuantizeImage(QuantizeInfo *quantize_info,Image *image)
 %
 %
 */
-Export unsigned int QuantizeImages(QuantizeInfo *quantize_info,Image *images)
+Export unsigned int QuantizeImages(const QuantizeInfo *quantize_info,
+  Image *images)
 {
   CubeInfo
     cube_info;
@@ -2197,6 +2111,8 @@ Export unsigned int QuantizeImages(QuantizeInfo *quantize_info,Image *images)
   for (i=0; image != (Image *) NULL; i++)
   {
     handler=SetMonitorHandler((MonitorHandler) NULL);
+    if (image->packets == (image->columns*image->rows))
+      CondenseImage(image);
     status=Classification(&cube_info,image);
     if (status == False)
       break;
@@ -2209,8 +2125,6 @@ Export unsigned int QuantizeImages(QuantizeInfo *quantize_info,Image *images)
       /*
         Reduce the number of colors in the continuous tone image sequence.
       */
-      if ((cube_info.colors >> 1) < number_colors)
-        quantize_info->dither=False;
       Reduction(&cube_info,number_colors);
       image=images;
       for (i=0; image != (Image *) NULL; i++)
@@ -2229,3 +2143,133 @@ Export unsigned int QuantizeImages(QuantizeInfo *quantize_info,Image *images)
   DestroyCubeInfo(&cube_info);
   return(status);
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++   R e d u c e                                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method Reduce traverses the color cube tree and prunes any node whose
+%  quantization error falls below a particular threshold.
+%
+%  The format of the Reduce routine is:
+%
+%      Reduce(cube_info,node_info)
+%
+%  A description of each parameter follows.
+%
+%    o cube: A pointer to the Cube structure.
+%
+%    o node_info: pointer to node in color cube tree that is to be pruned.
+%
+%
+*/
+static void Reduce(CubeInfo *cube_info,const NodeInfo *node_info)
+{
+  register unsigned int
+    id;
+
+  /*
+    Traverse any children.
+  */
+  if (node_info->census != 0)
+    for (id=0; id < 8; id++)
+      if (node_info->census & (1 << id))
+        Reduce(cube_info,node_info->child[id]);
+  if (node_info->quantization_error <= cube_info->pruning_threshold)
+    PruneChild(cube_info,node_info);
+  else
+    {
+      /*
+        Find minimum pruning threshold.
+      */
+      if (node_info->number_unique > 0)
+        cube_info->colors++;
+      if (node_info->quantization_error < cube_info->next_pruning_threshold)
+        cube_info->next_pruning_threshold=node_info->quantization_error;
+    }
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++   R e d u c t i o n                                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method Reduction repeatedly prunes the tree until the number of nodes
+%  with n2 > 0 is less than or equal to the maximum number of colors allowed
+%  in the output image.  On any given iteration over the tree, it selects
+%  those nodes whose E value is minimal for pruning and merges their
+%  color statistics upward. It uses a pruning threshold, Ep, to govern
+%  node selection as follows:
+%
+%    Ep = 0
+%    while number of nodes with (n2 > 0) > required maximum number of colors
+%      prune all nodes such that E <= Ep
+%      Set Ep to minimum E in remaining nodes
+%
+%  This has the effect of minimizing any quantization error when merging
+%  two nodes together.
+%
+%  When a node to be pruned has offspring, the pruning procedure invokes
+%  itself recursively in order to prune the tree from the leaves upward.
+%  n2,  Sr, Sg,  and  Sb in a node being pruned are always added to the
+%  corresponding data in that node's parent.  This retains the pruned
+%  node's color characteristics for later averaging.
+%
+%  For each node, n2 pixels exist for which that node represents the
+%  smallest volume in RGB space containing those pixel's colors.  When n2
+%  > 0 the node will uniquely define a color in the output image. At the
+%  beginning of reduction,  n2 = 0  for all nodes except a the leaves of
+%  the tree which represent colors present in the input image.
+%
+%  The other pixel count, n1, indicates the total number of colors
+%  within the cubic volume which the node represents.  This includes n1 -
+%  n2  pixels whose colors should be defined by nodes at a lower level in
+%  the tree.
+%
+%  The format of the Reduction routine is:
+%
+%      Reduction(cube_info,number_colors)
+%
+%  A description of each parameter follows.
+%
+%    o cube: A pointer to the Cube structure.
+%
+%    o number_colors: This integer value indicates the maximum number of
+%      colors in the quantized image or colormap.  The actual number of
+%      colors allocated to the colormap may be less than this value, but
+%      never more.
+%
+%
+*/
+static void Reduction(CubeInfo *cube_info,const unsigned int number_colors)
+{
+#define ReduceImageText  "  Reducing image colors...  "
+
+  unsigned int
+    span;
+
+  span=(unsigned int) cube_info->colors;
+  cube_info->next_pruning_threshold=0.0;
+  while (cube_info->colors > number_colors)
+  {
+    cube_info->pruning_threshold=cube_info->next_pruning_threshold;
+    cube_info->next_pruning_threshold=cube_info->root->quantization_error;
+    cube_info->colors=0;
+    Reduce(cube_info,cube_info->root);
+    ProgressMonitor(ReduceImageText,(unsigned int) (span-cube_info->colors),
+      span-number_colors+1);
+  }
+}
