@@ -1,5 +1,5 @@
 /*
-  ImageMagick Quantization declarations.
+  Methods to Reduce the Number of Unique Colors in an Image.
 */
 #ifndef _QUANTIZE_H
 #define _QUANTIZE_H
@@ -8,16 +8,6 @@
 extern "C" {
 #endif
 
-/*
-  Define declarations.
-*/
-#define CacheShift  (QuantumDepth-6)
-#define ErrorQueueLength  16
-#define MaxNodes  266817
-#define MaxSpan ((1 << MaxTreeDepth)-1)
-#define MaxTreeDepth  8
-#define NodesInAList  2048
-
 /*
   Typedef declarations.
 */
@@ -47,18 +37,21 @@ extern Export QuantizeInfo
   *CloneQuantizeInfo(const QuantizeInfo *);
 
 extern Export unsigned int
-  MapImage(Image *,Image *,const unsigned int),
-  MapImages(Image *,Image *,const unsigned int),
+  MapImage(Image *,const Image *,const unsigned int),
+  MapImages(Image *,const Image *,const unsigned int),
   QuantizationError(Image *),
-  QuantizeImage(QuantizeInfo *,Image *),
-  QuantizeImages(QuantizeInfo *,Image *),
+  QuantizeImage(const QuantizeInfo *,Image *),
+  QuantizeImages(const QuantizeInfo *,Image *),
   QueryColorName(const ColorPacket *,char *),
   SegmentImage(Image *,const ColorspaceType,const unsigned int,const double,
     const double);
 
+extern Export unsigned long
+  GetNumberColors(const Image *,FILE *);
+
 extern Export void
-  GetQuantizeInfo(QuantizeInfo *),
-  NumberColors(Image *,FILE *);
+  DestroyQuantizeInfo(QuantizeInfo *),
+  GetQuantizeInfo(QuantizeInfo *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
