@@ -52,6 +52,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 #include "Colorlist.h"
 
 /*
@@ -237,35 +238,39 @@ Export char *BaseFilename(const char *name)
 %  Method CloneString allocates memory for the destination string and copies
 %  the source string to that memory location.
 %
-%  The format of the CloneString routine is:
+%  The format of the (void) CloneString routine is:
 %
-%      CloneString(destination,source)
+%      status=CloneString(destination,source)
 %
 %  A description of each parameter follows:
 %
+%    o status:  Method IsAccessible returns True is the string is cloned,
+%      otherwise False is returned.
+%
 %    o destination:  A pointer to a character string.
 %
 %    o source: A character string.
 %
 %
 */
-Export void CloneString(char **destination,const char *source)
+Export unsigned int CloneString(char **destination,const char *source)
 {
   assert(destination != (char **) NULL);
   if (*destination != (char *) NULL)
     FreeMemory(*destination);
   *destination=(char *) NULL;
   if (source == (const char *) NULL)
-    return;
+    return(True);
   *destination=(char *) 
     AllocateMemory(Max(Extent(source)+1,MaxTextExtent)*sizeof(char));
   if (*destination == (char *) NULL)
     {
       MagickWarning(ResourceLimitWarning,"Unable to allocate string",
         "Memory allocation failed");
-      return;
+      return(False);
     }
   (void) strcpy(*destination,source);
+  return(True);
 }
 
 /*
@@ -813,7 +818,7 @@ Export int GetGeometry(const char *image_geometry,int *x,int *y,
 %
 %
 */
-Export int GlobExpression(char *expression,const char *pattern)
+Export int GlobExpression(const char *expression,const char *pattern)
 {
   ImageInfo
     image_info;
@@ -957,7 +962,7 @@ Export int GlobExpression(char *expression,const char *pattern)
         int
           match;
 
-        register char
+        register const char
           *p;
 
         pattern++;
@@ -1051,10 +1056,10 @@ Export int GlobExpression(char *expression,const char *pattern)
 %
 %  A description of each parameter follows.
 %
-%   o  status:  Method IsAccessible returns True is the file as defined by
+%    o status:  Method IsAccessible returns True is the file as defined by
 %      filename is accessible, otherwise False is returned.
 %
-%   o  filename:  Specifies a pointer to an array of characters.  The unique
+%    o filename:  Specifies a pointer to an array of characters.  The unique
 %      file name is returned in this array.
 %
 %
@@ -2078,21 +2083,21 @@ Export char *PostscriptGeometry(const char *page)
     *PageSizes[][2]=
     {
       { "11x17", "792x1224>" },
-      { "Ledger", "1224x792>" },
-      { "Legal", "612x1008>" },
-      { "Letter", "612x792>" },
-      { "LetterSmall", "612x792>" },
-      { "ArchE", "2592x3456>" },
-      { "ArchD", "1728x2592>" },
-      { "ArchC", "1296x1728>" },
-      { "ArchB", "864x1296>" },
-      { "ArchA", "648x864>" },
+      { "LEDGER", "1224x792>" },
+      { "LEGAL", "612x1008>" },
+      { "LETTER", "612x792>" },
+      { "LETTERSMALL", "612x792>" },
+      { "ARCHE", "2592x3456>" },
+      { "ARCHD", "1728x2592>" },
+      { "ARCHC", "1296x1728>" },
+      { "ARCHB", "864x1296>" },
+      { "ARCHA", "648x864>" },
       { "A0", "2380x3368>" },
       { "A1", "1684x2380>" },
       { "A2", "1190x1684>" },
       { "A3", "842x1190>" },
       { "A4", "595x842>" },
-      { "A4Small", "595x842>" },
+      { "A4SMALL", "595x842>" },
       { "A5", "421x595>" },
       { "A6", "297x421>" },
       { "A7", "210x297>" },
@@ -2112,9 +2117,9 @@ Export char *PostscriptGeometry(const char *page)
       { "C4", "649x918>" },
       { "C5", "459x649>" },
       { "C6", "323x459>" },
-      { "Flsa", "612x936>" },
-      { "Flse", "612x936>" },
-      { "HalfLetter", "396x612>" },
+      { "FLSA", "612x936>" },
+      { "FLSE", "612x936>" },
+      { "HALFLETTER", "396x612>" },
       { (char *) NULL, (char *) NULL }
     };
 
@@ -2312,8 +2317,8 @@ Export char *SetClientName(const char *name)
   if (name != (char *) NULL)
     {
       (void) strcpy(client_name,BaseFilename(name));
-      setlocale(LC_ALL,"");
-      setlocale(LC_NUMERIC,"C");
+      (void) setlocale(LC_ALL,"");
+      (void) setlocale(LC_NUMERIC,"C");
     }
   return(client_name);
 }
@@ -2657,7 +2662,7 @@ Export void Strip(char *data)
 %
 %
 */
-Export int SystemCommand(unsigned int verbose,char *command)
+Export int SystemCommand(const unsigned int verbose,const char *command)
 {
   int
     status;
