@@ -126,7 +126,6 @@
 %    -threshold value     threshold the image
 %    -transparent color   make this color transparent within the image
 %    -treedepth value     depth of the color classification tree
-%    -undercolor geometry control undercolor removal and black generation
 %    -units type          PixelsPerInch, PixelsPerCentimeter, or Undefined
 %    -verbose             print detailed information about the image
 %    -view                FlashPix viewing transforms
@@ -145,6 +144,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -248,7 +248,6 @@ static void Usage(const char *client_name)
       "-threshold value     threshold the image",
       "-transparent color   make this color transparent within the image",
       "-treedepth value     depth of the color classification tree",
-      "-undercolor geometry control undercolor removal and black generation",
       "-units type          PixelsPerInch, PixelsPerCentimeter, or Undefined",
       "-verbose             print detailed information about the image",
       "-view                FlashPix viewing transforms",
@@ -368,7 +367,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing background color",option);
-                  CloneString(&image_info.background_color,argv[i]);
+                  (void) CloneString(&image_info.background_color,argv[i]);
                 }
               break;
             }
@@ -400,7 +399,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing border color",option);
-                  CloneString(&image_info.border_color,argv[i]);
+                  (void) CloneString(&image_info.border_color,argv[i]);
                 }
               break;
             }
@@ -412,7 +411,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing box color",option);
-                  CloneString(&image_info.box,argv[i]);
+                  (void) CloneString(&image_info.box,argv[i]);
                 }
               break;
             }
@@ -575,7 +574,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info.density,argv[i]);
                 }
               break;
             }
@@ -601,7 +600,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  CloneString(&image_info.server_name,argv[i]);
+                  (void) CloneString(&image_info.server_name,argv[i]);
                 }
               break;
             }
@@ -715,7 +714,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing font name",option);
-                  CloneString(&image_info.font,argv[i]);
+                  (void) CloneString(&image_info.font,argv[i]);
                 }
               break;
             }
@@ -727,7 +726,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing image type",option);
-                  CloneString(&format,argv[i]);
+                  (void) CloneString(&format,argv[i]);
                   (void) strcpy(image_info.filename,format);
                   (void) strcat(image_info.filename,":");
                   SetImageInfo(&image_info,False);
@@ -950,7 +949,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing matte color",option);
-                  CloneString(&image_info.matte_color,argv[i]);
+                  (void) CloneString(&image_info.matte_color,argv[i]);
                 }
               break;
             }
@@ -1046,7 +1045,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing pen color",option);
-                  CloneString(&image_info.pen,argv[i]);
+                  (void) CloneString(&image_info.pen,argv[i]);
                 }
               break;
             }
@@ -1204,7 +1203,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.size,argv[i]);
+                  (void) CloneString(&image_info.size,argv[i]);
                 }
               break;
             }
@@ -1251,7 +1250,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing filename",option);
-                  CloneString(&image_info.texture,argv[i]);
+                  (void) CloneString(&image_info.texture,argv[i]);
                 }
               break;
             }
@@ -1290,19 +1289,6 @@ int main(int argc,char **argv)
         }
         case 'u':
         {
-          if (strncmp("undercolor",option+1,3) == 0)
-            {
-              image_info.undercolor=(char *) NULL;
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing undercolor geometry",
-                      option);
-                  CloneString(&image_info.undercolor,argv[i]);
-                }
-              break;
-            }
           if (strncmp("units",option+1,3) == 0)
             {
               image_info.units=UndefinedResolution;
@@ -1338,7 +1324,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing view transform",option);
-                  CloneString(&image_info.view,argv[i]);
+                  (void) CloneString(&image_info.view,argv[i]);
                 }
               break;
             }
