@@ -140,6 +140,7 @@
   Include declarations.
 */
 #include "magick.h"
+#include "defines.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -334,8 +335,8 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing color",option);
-                  CloneString(&image_info.background_color,argv[i]);
-                  CloneString(&montage_info.background_color,argv[i]);
+                  (void) CloneString(&image_info.background_color,argv[i]);
+                  (void) CloneString(&montage_info.background_color,argv[i]);
                 }
               break;
             }
@@ -348,8 +349,8 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing color",option);
-                  CloneString(&image_info.border_color,argv[i]);
-                  CloneString(&montage_info.border_color,argv[i]);
+                  (void) CloneString(&image_info.border_color,argv[i]);
+                  (void) CloneString(&montage_info.border_color,argv[i]);
                 }
               break;
             }
@@ -534,7 +535,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.density,argv[i]);
+                  (void) CloneString(&image_info.density,argv[i]);
                 }
               break;
             }
@@ -546,7 +547,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing server name",option);
-                  CloneString(&image_info.server_name,argv[i]);
+                  (void) CloneString(&image_info.server_name,argv[i]);
                 }
               break;
             }
@@ -635,8 +636,8 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing font name",option);
-                  CloneString(&image_info.font,argv[i]);
-                  CloneString(&montage_info.font,image_info.font);
+                  (void) CloneString(&image_info.font,argv[i]);
+                  (void) CloneString(&montage_info.font,image_info.font);
                 }
               break;
             }
@@ -649,7 +650,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&montage_info.frame,argv[i]);
+                  (void) CloneString(&montage_info.frame,argv[i]);
                 }
               break;
             }
@@ -673,7 +674,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&montage_info.geometry,argv[i]);
+                  (void) CloneString(&montage_info.geometry,argv[i]);
                 }
               break;
             }
@@ -783,8 +784,8 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing color",option);
-                  CloneString(&image_info.matte_color,argv[i]);
-                  CloneString(&montage_info.matte_color,argv[i]);
+                  (void) CloneString(&image_info.matte_color,argv[i]);
+                  (void) CloneString(&montage_info.matte_color,argv[i]);
                 }
               break;
             }
@@ -803,7 +804,7 @@ int main(int argc,char **argv)
                   if (Latin1Compare("frame",option) == 0)
                     {
                       mode=FrameMode;
-                      CloneString(&montage_info.frame,DefaultTileFrame);
+                      (void) CloneString(&montage_info.frame,DefaultTileFrame);
                       montage_info.shadow=True;
                       break;
                     }
@@ -820,7 +821,7 @@ int main(int argc,char **argv)
                       mode=ConcatenateMode;
                       montage_info.frame=(char *) NULL;
                       montage_info.shadow=False;
-                      CloneString(&montage_info.geometry,"+0+0");
+                      (void) CloneString(&montage_info.geometry,"+0+0");
                       montage_info.border_width=0;
                       break;
                     }
@@ -866,8 +867,8 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing pen color",option);
-                  CloneString(&image_info.pen,argv[i]);
-                  CloneString(&montage_info.pen,argv[i]);
+                  (void) CloneString(&image_info.pen,argv[i]);
+                  (void) CloneString(&montage_info.pen,argv[i]);
                 }
               break;
             }
@@ -955,7 +956,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&image_info.size,argv[i]);
+                  (void) CloneString(&image_info.size,argv[i]);
                 }
               break;
             }
@@ -972,7 +973,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing filename",option);
-                  CloneString(&montage_info.texture,argv[i]);
+                  (void) CloneString(&montage_info.texture,argv[i]);
                 }
               break;
             }
@@ -984,7 +985,7 @@ int main(int argc,char **argv)
                   i++;
                   if ((i == argc) || !IsGeometry(argv[i]))
                     MagickError(OptionError,"Missing geometry",option);
-                  CloneString(&montage_info.tile,argv[i]);
+                  (void) CloneString(&montage_info.tile,argv[i]);
                 }
               break;
             }
@@ -996,7 +997,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing title",option);
-                  CloneString(&montage_info.title,argv[i]);
+                  (void) CloneString(&montage_info.title,argv[i]);
                 }
               break;
             }
@@ -1008,7 +1009,7 @@ int main(int argc,char **argv)
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing color",option);
-                  CloneString(&transparent_color,argv[i]);
+                  (void) CloneString(&transparent_color,argv[i]);
                 }
               break;
             }
